@@ -1,8 +1,8 @@
 from .__base import FarasaBase
 
+
 class FarasaDiacritizer(FarasaBase):
+    task = "diacritize"
 
-    task = 'diacritize'
-
-    def diacritize(self,text):
-        return self._do_task(text=text)
\ No newline at end of file
+    def diacritize(self, text):
+        return self._do_task(text=text)
