@@ -1,8 +1,8 @@
 from .__base import FarasaBase
 
+
 class FarasaNamedEntityRecognizer(FarasaBase):
+    task = "NER"
 
-    task = 'NER'
-
-    def recognize(self,text):
-        return self._do_task(text=text)
\ No newline at end of file
+    def recognize(self, text):
+        return self._do_task(text=text)
