@@ -1,8 +1,8 @@
 from .__base import FarasaBase
 
+
 class FarasaStemmer(FarasaBase):
-    
-    task = 'stem'
-    
+    task = "stem"
+
     def stem(self, text):
-        return self._do_task(text=text)
\ No newline at end of file
+        return self._do_task(text=text)
